Module coordinate

Module coordinate 

Modules

cartesian
polar

Structs

CoordLayout
Describes the layout preferences and geometric behaviors of a coordinate system.
Rect
A simple rectangle representing a physical area on the canvas. This defines where the coordinate system is allowed to draw.

Enums

CoordSystem
Supported coordinate systems for the chart.

Traits

CoordinateTrait
The core interface for all coordinate systems in Charton.